@@ -38,11 +38,13 @@ class AutoscalingClient(NamespacedClient):
         timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Delete an autoscaling policy. NOTE: This feature is designed for indirect use
-        by Elasticsearch Service, Elastic Cloud Enterprise, and Elastic Cloud on Kubernetes.
-        Direct use is not supported.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/autoscaling-delete-autoscaling-policy.html>`_
+          <p>Delete an autoscaling policy.</p>
+          <p>NOTE: This feature is designed for indirect use by Elasticsearch Service, Elastic Cloud Enterprise, and Elastic Cloud on Kubernetes. Direct use is not supported.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-autoscaling-delete-autoscaling-policy>`_
 
         :param name: the name of the autoscaling policy
         :param master_timeout: Period to wait for a connection to the master node. If
@@ -89,20 +91,20 @@ class AutoscalingClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Get the autoscaling capacity. NOTE: This feature is designed for indirect use
-        by Elasticsearch Service, Elastic Cloud Enterprise, and Elastic Cloud on Kubernetes.
-        Direct use is not supported. This API gets the current autoscaling capacity based
-        on the configured autoscaling policy. It will return information to size the
-        cluster appropriately to the current workload. The `required_capacity` is calculated
-        as the maximum of the `required_capacity` result of all individual deciders that
-        are enabled for the policy. The operator should verify that the `current_nodes`
-        match the operator’s knowledge of the cluster to avoid making autoscaling decisions
-        based on stale or incomplete information. The response contains decider-specific
-        information you can use to diagnose how and why autoscaling determined a certain
-        capacity was required. This information is provided for diagnosis only. Do not
-        use this information to make autoscaling decisions.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/autoscaling-get-autoscaling-capacity.html>`_
+          <p>Get the autoscaling capacity.</p>
+          <p>NOTE: This feature is designed for indirect use by Elasticsearch Service, Elastic Cloud Enterprise, and Elastic Cloud on Kubernetes. Direct use is not supported.</p>
+          <p>This API gets the current autoscaling capacity based on the configured autoscaling policy.
+          It will return information to size the cluster appropriately to the current workload.</p>
+          <p>The <code>required_capacity</code> is calculated as the maximum of the <code>required_capacity</code> result of all individual deciders that are enabled for the policy.</p>
+          <p>The operator should verify that the <code>current_nodes</code> match the operator’s knowledge of the cluster to avoid making autoscaling decisions based on stale or incomplete information.</p>
+          <p>The response contains decider-specific information you can use to diagnose how and why autoscaling determined a certain capacity was required.
+          This information is provided for diagnosis only.
+          Do not use this information to make autoscaling decisions.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-autoscaling-get-autoscaling-capacity>`_
 
         :param master_timeout: Period to wait for a connection to the master node. If
             no response is received before the timeout expires, the request fails and
@@ -143,11 +145,13 @@ class AutoscalingClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Get an autoscaling policy. NOTE: This feature is designed for indirect use by
-        Elasticsearch Service, Elastic Cloud Enterprise, and Elastic Cloud on Kubernetes.
-        Direct use is not supported.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/autoscaling-get-autoscaling-capacity.html>`_
+          <p>Get an autoscaling policy.</p>
+          <p>NOTE: This feature is designed for indirect use by Elasticsearch Service, Elastic Cloud Enterprise, and Elastic Cloud on Kubernetes. Direct use is not supported.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-autoscaling-get-autoscaling-capacity>`_
 
         :param name: the name of the autoscaling policy
         :param master_timeout: Period to wait for a connection to the master node. If
@@ -196,11 +200,13 @@ class AutoscalingClient(NamespacedClient):
         timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Create or update an autoscaling policy. NOTE: This feature is designed for indirect
-        use by Elasticsearch Service, Elastic Cloud Enterprise, and Elastic Cloud on
-        Kubernetes. Direct use is not supported.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/autoscaling-put-autoscaling-policy.html>`_
+          <p>Create or update an autoscaling policy.</p>
+          <p>NOTE: This feature is designed for indirect use by Elasticsearch Service, Elastic Cloud Enterprise, and Elastic Cloud on Kubernetes. Direct use is not supported.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-autoscaling-put-autoscaling-policy>`_
 
         :param name: the name of the autoscaling policy
         :param policy:
