@@ -39,13 +39,19 @@ class DanglingIndicesClient(NamespacedClient):
         timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Deletes the specified dangling index
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/modules-gateway-dangling-indices.html>`_
+          <p>Delete a dangling index.
+          If Elasticsearch encounters index data that is absent from the current cluster state, those indices are considered to be dangling.
+          For example, this can happen if you delete more than <code>cluster.indices.tombstones.size</code> indices while an Elasticsearch node is offline.</p>
 
-        :param index_uuid: The UUID of the dangling index
-        :param accept_data_loss: Must be set to true in order to delete the dangling
-            index
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-dangling-indices-delete-dangling-index>`_
+
+        :param index_uuid: The UUID of the index to delete. Use the get dangling indices
+            API to find the UUID.
+        :param accept_data_loss: This parameter must be set to true to acknowledge that
+            it will no longer be possible to recove data from the dangling index.
         :param master_timeout: Specify timeout for connection to master
         :param timeout: Explicit operation timeout
         """
@@ -94,13 +100,22 @@ class DanglingIndicesClient(NamespacedClient):
         timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Imports the specified dangling index
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/modules-gateway-dangling-indices.html>`_
+          <p>Import a dangling index.</p>
+          <p>If Elasticsearch encounters index data that is absent from the current cluster state, those indices are considered to be dangling.
+          For example, this can happen if you delete more than <code>cluster.indices.tombstones.size</code> indices while an Elasticsearch node is offline.</p>
 
-        :param index_uuid: The UUID of the dangling index
-        :param accept_data_loss: Must be set to true in order to import the dangling
-            index
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-dangling-indices-import-dangling-index>`_
+
+        :param index_uuid: The UUID of the index to import. Use the get dangling indices
+            API to locate the UUID.
+        :param accept_data_loss: This parameter must be set to true to import a dangling
+            index. Because Elasticsearch cannot know where the dangling index data came
+            from or determine which shard copies are fresh and which are stale, it cannot
+            guarantee that the imported data represents the latest state of the index
+            when it was last in the cluster.
         :param master_timeout: Specify timeout for connection to master
         :param timeout: Explicit operation timeout
         """
@@ -145,9 +160,15 @@ class DanglingIndicesClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Returns all dangling indices.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/modules-gateway-dangling-indices.html>`_
+          <p>Get the dangling indices.</p>
+          <p>If Elasticsearch encounters index data that is absent from the current cluster state, those indices are considered to be dangling.
+          For example, this can happen if you delete more than <code>cluster.indices.tombstones.size</code> indices while an Elasticsearch node is offline.</p>
+          <p>Use this API to list dangling indices, which you can then import or delete.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-dangling-indices-list-dangling-indices>`_
         """
         __path_parts: t.Dict[str, str] = {}
         __path = "/_dangling"
