@@ -38,16 +38,20 @@ class IngestClient(NamespacedClient):
         timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Deletes a geoip database configuration.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/TODO.html>`_
+          <p>Delete GeoIP database configurations.</p>
+          <p>Delete one or more IP geolocation database configurations.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-ingest-delete-geoip-database>`_
 
         :param id: A comma-separated list of geoip database configurations to delete
-        :param master_timeout: Period to wait for a connection to the master node. If
-            no response is received before the timeout expires, the request fails and
-            returns an error.
-        :param timeout: Period to wait for a response. If no response is received before
-            the timeout expires, the request fails and returns an error.
+        :param master_timeout: The period to wait for a connection to the master node.
+            If no response is received before the timeout expires, the request fails
+            and returns an error.
+        :param timeout: The period to wait for a response. If no response is received
+            before the timeout expires, the request fails and returns an error.
         """
         if id in SKIP_IN_PATH:
             raise ValueError("Empty value passed for parameter 'id'")
@@ -76,6 +80,62 @@ class IngestClient(NamespacedClient):
             path_parts=__path_parts,
         )
 
+    @_rewrite_parameters()
+    def delete_ip_location_database(
+        self,
+        *,
+        id: t.Union[str, t.Sequence[str]],
+        error_trace: t.Optional[bool] = None,
+        filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
+        human: t.Optional[bool] = None,
+        master_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
+        pretty: t.Optional[bool] = None,
+        timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
+    ) -> ObjectApiResponse[t.Any]:
+        """
+        .. raw:: html
+
+          <p>Delete IP geolocation database configurations.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-ingest-delete-ip-location-database>`_
+
+        :param id: A comma-separated list of IP location database configurations.
+        :param master_timeout: The period to wait for a connection to the master node.
+            If no response is received before the timeout expires, the request fails
+            and returns an error. A value of `-1` indicates that the request should never
+            time out.
+        :param timeout: The period to wait for a response. If no response is received
+            before the timeout expires, the request fails and returns an error. A value
+            of `-1` indicates that the request should never time out.
+        """
+        if id in SKIP_IN_PATH:
+            raise ValueError("Empty value passed for parameter 'id'")
+        __path_parts: t.Dict[str, str] = {"id": _quote(id)}
+        __path = f'/_ingest/ip_location/database/{__path_parts["id"]}'
+        __query: t.Dict[str, t.Any] = {}
+        if error_trace is not None:
+            __query["error_trace"] = error_trace
+        if filter_path is not None:
+            __query["filter_path"] = filter_path
+        if human is not None:
+            __query["human"] = human
+        if master_timeout is not None:
+            __query["master_timeout"] = master_timeout
+        if pretty is not None:
+            __query["pretty"] = pretty
+        if timeout is not None:
+            __query["timeout"] = timeout
+        __headers = {"accept": "application/json"}
+        return self.perform_request(  # type: ignore[return-value]
+            "DELETE",
+            __path,
+            params=__query,
+            headers=__headers,
+            endpoint_id="ingest.delete_ip_location_database",
+            path_parts=__path_parts,
+        )
+
     @_rewrite_parameters()
     def delete_pipeline(
         self,
@@ -89,9 +149,13 @@ class IngestClient(NamespacedClient):
         timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Deletes one or more existing ingest pipeline.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/delete-pipeline-api.html>`_
+          <p>Delete pipelines.
+          Delete one or more ingest pipelines.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-ingest-delete-pipeline>`_
 
         :param id: Pipeline ID or wildcard expression of pipeline IDs used to limit the
             request. To delete all ingest pipelines in a cluster, use a value of `*`.
@@ -138,9 +202,13 @@ class IngestClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Gets download statistics for GeoIP2 databases used with the geoip processor.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/geoip-processor.html>`_
+          <p>Get GeoIP statistics.
+          Get download statistics for GeoIP2 databases that are used with the GeoIP processor.</p>
+
+
+        `<https://www.elastic.co/docs/reference/enrich-processor/geoip-processor>`_
         """
         __path_parts: t.Dict[str, str] = {}
         __path = "/_ingest/geoip/stats"
@@ -171,20 +239,20 @@ class IngestClient(NamespacedClient):
         error_trace: t.Optional[bool] = None,
         filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         human: t.Optional[bool] = None,
-        master_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Returns information about one or more geoip database configurations.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/TODO.html>`_
+          <p>Get GeoIP database configurations.</p>
+          <p>Get information about one or more IP geolocation database configurations.</p>
 
-        :param id: Comma-separated list of database configuration IDs to retrieve. Wildcard
-            (`*`) expressions are supported. To get all database configurations, omit
-            this parameter or use `*`.
-        :param master_timeout: Period to wait for a connection to the master node. If
-            no response is received before the timeout expires, the request fails and
-            returns an error.
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-ingest-get-geoip-database>`_
+
+        :param id: A comma-separated list of database configuration IDs to retrieve.
+            Wildcard (`*`) expressions are supported. To get all database configurations,
+            omit this parameter or use `*`.
         """
         __path_parts: t.Dict[str, str]
         if id not in SKIP_IN_PATH:
@@ -194,6 +262,59 @@ class IngestClient(NamespacedClient):
             __path_parts = {}
             __path = "/_ingest/geoip/database"
         __query: t.Dict[str, t.Any] = {}
+        if error_trace is not None:
+            __query["error_trace"] = error_trace
+        if filter_path is not None:
+            __query["filter_path"] = filter_path
+        if human is not None:
+            __query["human"] = human
+        if pretty is not None:
+            __query["pretty"] = pretty
+        __headers = {"accept": "application/json"}
+        return self.perform_request(  # type: ignore[return-value]
+            "GET",
+            __path,
+            params=__query,
+            headers=__headers,
+            endpoint_id="ingest.get_geoip_database",
+            path_parts=__path_parts,
+        )
+
+    @_rewrite_parameters()
+    def get_ip_location_database(
+        self,
+        *,
+        id: t.Optional[t.Union[str, t.Sequence[str]]] = None,
+        error_trace: t.Optional[bool] = None,
+        filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
+        human: t.Optional[bool] = None,
+        master_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
+        pretty: t.Optional[bool] = None,
+    ) -> ObjectApiResponse[t.Any]:
+        """
+        .. raw:: html
+
+          <p>Get IP geolocation database configurations.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-ingest-get-ip-location-database>`_
+
+        :param id: Comma-separated list of database configuration IDs to retrieve. Wildcard
+            (`*`) expressions are supported. To get all database configurations, omit
+            this parameter or use `*`.
+        :param master_timeout: The period to wait for a connection to the master node.
+            If no response is received before the timeout expires, the request fails
+            and returns an error. A value of `-1` indicates that the request should never
+            time out.
+        """
+        __path_parts: t.Dict[str, str]
+        if id not in SKIP_IN_PATH:
+            __path_parts = {"id": _quote(id)}
+            __path = f'/_ingest/ip_location/database/{__path_parts["id"]}'
+        else:
+            __path_parts = {}
+            __path = "/_ingest/ip_location/database"
+        __query: t.Dict[str, t.Any] = {}
         if error_trace is not None:
             __query["error_trace"] = error_trace
         if filter_path is not None:
@@ -210,7 +331,7 @@ class IngestClient(NamespacedClient):
             __path,
             params=__query,
             headers=__headers,
-            endpoint_id="ingest.get_geoip_database",
+            endpoint_id="ingest.get_ip_location_database",
             path_parts=__path_parts,
         )
 
@@ -227,10 +348,14 @@ class IngestClient(NamespacedClient):
         summary: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Returns information about one or more ingest pipelines. This API returns a local
-        reference of the pipeline.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/get-pipeline-api.html>`_
+          <p>Get pipelines.</p>
+          <p>Get information about one or more ingest pipelines.
+          This API returns a local reference of the pipeline.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-ingest-get-pipeline>`_
 
         :param id: Comma-separated list of pipeline IDs to retrieve. Wildcard (`*`) expressions
             are supported. To get all ingest pipelines, omit this parameter or use `*`.
@@ -279,12 +404,15 @@ class IngestClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Extracts structured fields out of a single text field within a document. You
-        choose which field to extract matched fields from, as well as the grok pattern
-        you expect will match. A grok pattern is like a regular expression that supports
-        aliased expressions that can be reused.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/grok-processor.html>`_
+          <p>Run a grok processor.
+          Extract structured fields out of a single text field within a document.
+          You must choose which field to extract matched fields from, as well as the grok pattern you expect will match.
+          A grok pattern is like a regular expression that supports aliased expressions that can be reused.</p>
+
+
+        `<https://www.elastic.co/docs/reference/enrich-processor/grok-processor>`_
         """
         __path_parts: t.Dict[str, str] = {}
         __path = "/_ingest/processor/grok"
@@ -325,9 +453,13 @@ class IngestClient(NamespacedClient):
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Returns information about one or more geoip database configurations.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/TODO.html>`_
+          <p>Create or update a GeoIP database configuration.</p>
+          <p>Refer to the create or update IP geolocation database configuration API.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-ingest-put-geoip-database>`_
 
         :param id: ID of the database configuration to create or update.
         :param maxmind: The configuration necessary to identify which IP geolocation
@@ -381,13 +513,92 @@ class IngestClient(NamespacedClient):
         )
 
     @_rewrite_parameters(
-        body_fields=("description", "meta", "on_failure", "processors", "version"),
+        body_name="configuration",
+    )
+    def put_ip_location_database(
+        self,
+        *,
+        id: str,
+        configuration: t.Optional[t.Mapping[str, t.Any]] = None,
+        body: t.Optional[t.Mapping[str, t.Any]] = None,
+        error_trace: t.Optional[bool] = None,
+        filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
+        human: t.Optional[bool] = None,
+        master_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
+        pretty: t.Optional[bool] = None,
+        timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
+    ) -> ObjectApiResponse[t.Any]:
+        """
+        .. raw:: html
+
+          <p>Create or update an IP geolocation database configuration.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-ingest-put-ip-location-database>`_
+
+        :param id: The database configuration identifier.
+        :param configuration:
+        :param master_timeout: The period to wait for a connection to the master node.
+            If no response is received before the timeout expires, the request fails
+            and returns an error. A value of `-1` indicates that the request should never
+            time out.
+        :param timeout: The period to wait for a response from all relevant nodes in
+            the cluster after updating the cluster metadata. If no response is received
+            before the timeout expires, the cluster metadata update still applies but
+            the response indicates that it was not completely acknowledged. A value of
+            `-1` indicates that the request should never time out.
+        """
+        if id in SKIP_IN_PATH:
+            raise ValueError("Empty value passed for parameter 'id'")
+        if configuration is None and body is None:
+            raise ValueError(
+                "Empty value passed for parameters 'configuration' and 'body', one of them should be set."
+            )
+        elif configuration is not None and body is not None:
+            raise ValueError("Cannot set both 'configuration' and 'body'")
+        __path_parts: t.Dict[str, str] = {"id": _quote(id)}
+        __path = f'/_ingest/ip_location/database/{__path_parts["id"]}'
+        __query: t.Dict[str, t.Any] = {}
+        if error_trace is not None:
+            __query["error_trace"] = error_trace
+        if filter_path is not None:
+            __query["filter_path"] = filter_path
+        if human is not None:
+            __query["human"] = human
+        if master_timeout is not None:
+            __query["master_timeout"] = master_timeout
+        if pretty is not None:
+            __query["pretty"] = pretty
+        if timeout is not None:
+            __query["timeout"] = timeout
+        __body = configuration if configuration is not None else body
+        __headers = {"accept": "application/json", "content-type": "application/json"}
+        return self.perform_request(  # type: ignore[return-value]
+            "PUT",
+            __path,
+            params=__query,
+            headers=__headers,
+            body=__body,
+            endpoint_id="ingest.put_ip_location_database",
+            path_parts=__path_parts,
+        )
+
+    @_rewrite_parameters(
+        body_fields=(
+            "deprecated",
+            "description",
+            "meta",
+            "on_failure",
+            "processors",
+            "version",
+        ),
         parameter_aliases={"_meta": "meta"},
     )
     def put_pipeline(
         self,
         *,
         id: str,
+        deprecated: t.Optional[bool] = None,
         description: t.Optional[str] = None,
         error_trace: t.Optional[bool] = None,
         filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
@@ -403,12 +614,19 @@ class IngestClient(NamespacedClient):
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Creates or updates an ingest pipeline. Changes made using this API take effect
-        immediately.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/ingest.html>`_
+          <p>Create or update a pipeline.
+          Changes made using this API take effect immediately.</p>
+
+
+        `<https://www.elastic.co/docs/manage-data/ingest/transform-enrich/ingest-pipelines>`_
 
         :param id: ID of the ingest pipeline to create or update.
+        :param deprecated: Marks this ingest pipeline as deprecated. When a deprecated
+            ingest pipeline is referenced as the default or final pipeline when creating
+            or updating a non-deprecated index template, Elasticsearch will emit a deprecation
+            warning.
         :param description: Description of the ingest pipeline.
         :param if_version: Required version for optimistic concurrency control for pipeline
             updates
@@ -452,6 +670,8 @@ class IngestClient(NamespacedClient):
         if timeout is not None:
             __query["timeout"] = timeout
         if not __body:
+            if deprecated is not None:
+                __body["deprecated"] = deprecated
             if description is not None:
                 __body["description"] = description
             if meta is not None:
@@ -479,8 +699,8 @@ class IngestClient(NamespacedClient):
     def simulate(
         self,
         *,
-        id: t.Optional[str] = None,
         docs: t.Optional[t.Sequence[t.Mapping[str, t.Any]]] = None,
+        id: t.Optional[str] = None,
         error_trace: t.Optional[bool] = None,
         filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         human: t.Optional[bool] = None,
@@ -490,19 +710,26 @@ class IngestClient(NamespacedClient):
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Executes an ingest pipeline against a set of provided documents.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/simulate-pipeline-api.html>`_
+          <p>Simulate a pipeline.</p>
+          <p>Run an ingest pipeline against a set of provided documents.
+          You can either specify an existing pipeline to use with the provided documents or supply a pipeline definition in the body of the request.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-ingest-simulate>`_
 
-        :param id: Pipeline to test. If you don’t specify a `pipeline` in the request
-            body, this parameter is required.
         :param docs: Sample documents to test in the pipeline.
-        :param pipeline: Pipeline to test. If you don’t specify the `pipeline` request
+        :param id: The pipeline to test. If you don't specify a `pipeline` in the request
+            body, this parameter is required.
+        :param pipeline: The pipeline to test. If you don't specify the `pipeline` request
             path parameter, this parameter is required. If you specify both this and
             the request path parameter, the API only uses the request path parameter.
         :param verbose: If `true`, the response includes output data for each processor
             in the executed pipeline.
         """
+        if docs is None and body is None:
+            raise ValueError("Empty value passed for parameter 'docs'")
         __path_parts: t.Dict[str, str]
         if id not in SKIP_IN_PATH:
             __path_parts = {"id": _quote(id)}
