@@ -36,12 +36,15 @@ class MigrationClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Get deprecation information. Get information about different cluster, node, and
-        index level settings that use deprecated features that will be removed or changed
-        in the next major version. TIP: This APIs is designed for indirect use by the
-        Upgrade Assistant. You are strongly recommended to use the Upgrade Assistant.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/migration-api-deprecation.html>`_
+          <p>Get deprecation information.
+          Get information about different cluster, node, and index level settings that use deprecated features that will be removed or changed in the next major version.</p>
+          <p>TIP: This APIs is designed for indirect use by the Upgrade Assistant.
+          You are strongly recommended to use the Upgrade Assistant.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-migration-deprecations>`_
 
         :param index: Comma-separate list of data streams or indices to check. Wildcard
             (*) expressions are supported.
@@ -82,13 +85,16 @@ class MigrationClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Get feature migration information. Version upgrades sometimes require changes
-        to how features store configuration information and data in system indices. Check
-        which features need to be migrated and the status of any migrations that are
-        in progress. TIP: This API is designed for indirect use by the Upgrade Assistant.
-        You are strongly recommended to use the Upgrade Assistant.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/feature-migration-api.html>`_
+          <p>Get feature migration information.
+          Version upgrades sometimes require changes to how features store configuration information and data in system indices.
+          Check which features need to be migrated and the status of any migrations that are in progress.</p>
+          <p>TIP: This API is designed for indirect use by the Upgrade Assistant.
+          You are strongly recommended to use the Upgrade Assistant.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-migration-get-feature-upgrade-status>`_
         """
         __path_parts: t.Dict[str, str] = {}
         __path = "/_migration/system_features"
@@ -121,13 +127,16 @@ class MigrationClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Start the feature migration. Version upgrades sometimes require changes to how
-        features store configuration information and data in system indices. This API
-        starts the automatic migration process. Some functionality might be temporarily
-        unavailable during the migration process. TIP: The API is designed for indirect
-        use by the Upgrade Assistant. We strongly recommend you use the Upgrade Assistant.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/feature-migration-api.html>`_
+          <p>Start the feature migration.
+          Version upgrades sometimes require changes to how features store configuration information and data in system indices.
+          This API starts the automatic migration process.</p>
+          <p>Some functionality might be temporarily unavailable during the migration process.</p>
+          <p>TIP: The API is designed for indirect use by the Upgrade Assistant. We strongly recommend you use the Upgrade Assistant.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-migration-get-feature-upgrade-status>`_
         """
         __path_parts: t.Dict[str, str] = {}
         __path = "/_migration/system_features"
