@@ -37,9 +37,14 @@ class QueryRulesClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Delete a query rule. Delete a query rule within a query ruleset.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/delete-query-rule.html>`_
+          <p>Delete a query rule.
+          Delete a query rule within a query ruleset.
+          This is a destructive action that is only recoverable by re-adding the same rule with the create or update query rule API.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-query-rules-delete-rule>`_
 
         :param ruleset_id: The unique identifier of the query ruleset containing the
             rule to delete
@@ -85,9 +90,14 @@ class QueryRulesClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Delete a query ruleset.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/delete-query-ruleset.html>`_
+          <p>Delete a query ruleset.
+          Remove a query ruleset and its associated data.
+          This is a destructive action that is not recoverable.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-query-rules-delete-ruleset>`_
 
         :param ruleset_id: The unique identifier of the query ruleset to delete
         """
@@ -126,9 +136,13 @@ class QueryRulesClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Get a query rule. Get details about a query rule within a query ruleset.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/get-query-rule.html>`_
+          <p>Get a query rule.
+          Get details about a query rule within a query ruleset.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-query-rules-get-rule>`_
 
         :param ruleset_id: The unique identifier of the query ruleset containing the
             rule to retrieve
@@ -174,9 +188,13 @@ class QueryRulesClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Get a query ruleset. Get details about a query ruleset.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/get-query-ruleset.html>`_
+          <p>Get a query ruleset.
+          Get details about a query ruleset.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-query-rules-get-ruleset>`_
 
         :param ruleset_id: The unique identifier of the query ruleset
         """
@@ -217,12 +235,16 @@ class QueryRulesClient(NamespacedClient):
         size: t.Optional[int] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Get all query rulesets. Get summarized information about the query rulesets.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/list-query-rulesets.html>`_
+          <p>Get all query rulesets.
+          Get summarized information about the query rulesets.</p>
 
-        :param from_: Starting offset (default: 0)
-        :param size: specifies a max number of results to get
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-query-rules-list-rulesets>`_
+
+        :param from_: The offset from the first result to fetch.
+        :param size: The maximum number of results to retrieve.
         """
         __path_parts: t.Dict[str, str] = {}
         __path = "/_query_rules"
@@ -270,17 +292,28 @@ class QueryRulesClient(NamespacedClient):
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Create or update a query rule. Create or update a query rule within a query ruleset.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/put-query-rule.html>`_
+          <p>Create or update a query rule.
+          Create or update a query rule within a query ruleset.</p>
+          <p>IMPORTANT: Due to limitations within pinned queries, you can only pin documents using ids or docs, but cannot use both in single rule.
+          It is advised to use one or the other in query rulesets, to avoid errors.
+          Additionally, pinned queries have a maximum limit of 100 pinned hits.
+          If multiple matching rules pin more than 100 documents, only the first 100 documents are pinned in the order they are specified in the ruleset.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-query-rules-put-rule>`_
 
         :param ruleset_id: The unique identifier of the query ruleset containing the
-            rule to be created or updated
+            rule to be created or updated.
         :param rule_id: The unique identifier of the query rule within the specified
-            ruleset to be created or updated
-        :param actions:
-        :param criteria:
-        :param type:
+            ruleset to be created or updated.
+        :param actions: The actions to take when the rule is matched. The format of this
+            action depends on the rule type.
+        :param criteria: The criteria that must be met for the rule to be applied. If
+            multiple criteria are specified for a rule, all criteria must be met for
+            the rule to be applied.
+        :param type: The type of rule.
         :param priority:
         """
         if ruleset_id in SKIP_IN_PATH:
@@ -345,12 +378,21 @@ class QueryRulesClient(NamespacedClient):
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Create or update a query ruleset.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/put-query-ruleset.html>`_
+          <p>Create or update a query ruleset.
+          There is a limit of 100 rules per ruleset.
+          This limit can be increased by using the <code>xpack.applications.rules.max_rules_per_ruleset</code> cluster setting.</p>
+          <p>IMPORTANT: Due to limitations within pinned queries, you can only select documents using <code>ids</code> or <code>docs</code>, but cannot use both in single rule.
+          It is advised to use one or the other in query rulesets, to avoid errors.
+          Additionally, pinned queries have a maximum limit of 100 pinned hits.
+          If multiple matching rules pin more than 100 documents, only the first 100 documents are pinned in the order they are specified in the ruleset.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-query-rules-put-ruleset>`_
 
         :param ruleset_id: The unique identifier of the query ruleset to be created or
-            updated
+            updated.
         :param rules:
         """
         if ruleset_id in SKIP_IN_PATH:
@@ -398,14 +440,19 @@ class QueryRulesClient(NamespacedClient):
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Test a query ruleset. Evaluate match criteria against a query ruleset to identify
-        the rules that would match that criteria.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/test-query-ruleset.html>`_
+          <p>Test a query ruleset.
+          Evaluate match criteria against a query ruleset to identify the rules that would match that criteria.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-query-rules-test>`_
 
         :param ruleset_id: The unique identifier of the query ruleset to be created or
             updated
-        :param match_criteria:
+        :param match_criteria: The match criteria to apply to rules in the given query
+            ruleset. Match criteria should match the keys defined in the `criteria.metadata`
+            field of the rule.
         """
         if ruleset_id in SKIP_IN_PATH:
             raise ValueError("Empty value passed for parameter 'ruleset_id'")
