@@ -36,11 +36,26 @@ class SynonymsClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Deletes a synonym set
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/delete-synonyms-set.html>`_
+          <p>Delete a synonym set.</p>
+          <p>You can only delete a synonyms set that is not in use by any index analyzer.</p>
+          <p>Synonyms sets can be used in synonym graph token filters and synonym token filters.
+          These synonym filters can be used as part of search analyzers.</p>
+          <p>Analyzers need to be loaded when an index is restored (such as when a node starts, or the index becomes open).
+          Even if the analyzer is not used on any field mapping, it still needs to be loaded on the index recovery phase.</p>
+          <p>If any analyzers cannot be loaded, the index becomes unavailable and the cluster status becomes red or yellow as index shards are not available.
+          To prevent that, synonyms sets that are used in analyzers can't be deleted.
+          A delete request in this case will return a 400 response code.</p>
+          <p>To remove a synonyms set, you must first remove all indices that contain analyzers using it.
+          You can migrate an index by creating a new index that does not contain the token filter with the synonyms set, and use the reindex API in order to copy over the index data.
+          Once finished, you can delete the index.
+          When the synonyms set is not used in analyzers, you will be able to delete it.</p>
 
-        :param id: The id of the synonyms set to be deleted
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-synonyms-delete-synonym>`_
+
+        :param id: The synonyms set identifier to delete.
         """
         if id in SKIP_IN_PATH:
             raise ValueError("Empty value passed for parameter 'id'")
@@ -77,12 +92,16 @@ class SynonymsClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Deletes a synonym rule in a synonym set
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/delete-synonym-rule.html>`_
+          <p>Delete a synonym rule.
+          Delete a synonym rule from a synonym set.</p>
 
-        :param set_id: The id of the synonym set to be updated
-        :param rule_id: The id of the synonym rule to be deleted
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-synonyms-delete-synonym-rule>`_
+
+        :param set_id: The ID of the synonym set to update.
+        :param rule_id: The ID of the synonym rule to delete.
         """
         if set_id in SKIP_IN_PATH:
             raise ValueError("Empty value passed for parameter 'set_id'")
@@ -127,13 +146,16 @@ class SynonymsClient(NamespacedClient):
         size: t.Optional[int] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Retrieves a synonym set
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/get-synonyms-set.html>`_
+          <p>Get a synonym set.</p>
 
-        :param id: "The id of the synonyms set to be retrieved
-        :param from_: Starting offset for query rules to be retrieved
-        :param size: specifies a max number of query rules to retrieve
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-synonyms-get-synonym>`_
+
+        :param id: The synonyms set identifier to retrieve.
+        :param from_: The starting offset for query rules to retrieve.
+        :param size: The max number of query rules to retrieve.
         """
         if id in SKIP_IN_PATH:
             raise ValueError("Empty value passed for parameter 'id'")
@@ -174,12 +196,16 @@ class SynonymsClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Retrieves a synonym rule from a synonym set
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/get-synonym-rule.html>`_
+          <p>Get a synonym rule.
+          Get a synonym rule from a synonym set.</p>
 
-        :param set_id: The id of the synonym set to retrieve the synonym rule from
-        :param rule_id: The id of the synonym rule to retrieve
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-synonyms-get-synonym-rule>`_
+
+        :param set_id: The ID of the synonym set to retrieve the synonym rule from.
+        :param rule_id: The ID of the synonym rule to retrieve.
         """
         if set_id in SKIP_IN_PATH:
             raise ValueError("Empty value passed for parameter 'set_id'")
@@ -223,12 +249,16 @@ class SynonymsClient(NamespacedClient):
         size: t.Optional[int] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Retrieves a summary of all defined synonym sets
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/list-synonyms-sets.html>`_
+          <p>Get all synonym sets.
+          Get a summary of all defined synonym sets.</p>
 
-        :param from_: Starting offset
-        :param size: specifies a max number of results to get
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-synonyms-get-synonym>`_
+
+        :param from_: The starting offset for synonyms sets to retrieve.
+        :param size: The maximum number of synonyms sets to retrieve.
         """
         __path_parts: t.Dict[str, str] = {}
         __path = "/_synonyms"
@@ -272,12 +302,19 @@ class SynonymsClient(NamespacedClient):
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Creates or updates a synonym set.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/put-synonyms-set.html>`_
+          <p>Create or update a synonym set.
+          Synonyms sets are limited to a maximum of 10,000 synonym rules per set.
+          If you need to manage more synonym rules, you can create multiple synonym sets.</p>
+          <p>When an existing synonyms set is updated, the search analyzers that use the synonyms set are reloaded automatically for all indices.
+          This is equivalent to invoking the reload search analyzers API for all indices that use the synonyms set.</p>
 
-        :param id: The id of the synonyms set to be created or updated
-        :param synonyms_set: The synonym set information to update
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-synonyms-put-synonym>`_
+
+        :param id: The ID of the synonyms set to be created or updated.
+        :param synonyms_set: The synonym rules definitions for the synonyms set.
         """
         if id in SKIP_IN_PATH:
             raise ValueError("Empty value passed for parameter 'id'")
@@ -325,13 +362,20 @@ class SynonymsClient(NamespacedClient):
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Creates or updates a synonym rule in a synonym set
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/put-synonym-rule.html>`_
+          <p>Create or update a synonym rule.
+          Create or update a synonym rule in a synonym set.</p>
+          <p>If any of the synonym rules included is invalid, the API returns an error.</p>
+          <p>When you update a synonym rule, all analyzers using the synonyms set will be reloaded automatically to reflect the new rule.</p>
 
-        :param set_id: The id of the synonym set to be updated with the synonym rule
-        :param rule_id: The id of the synonym rule to be updated or created
-        :param synonyms:
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-synonyms-put-synonym-rule>`_
+
+        :param set_id: The ID of the synonym set.
+        :param rule_id: The ID of the synonym rule to be updated or created.
+        :param synonyms: The synonym rule information definition, which must be in Solr
+            format.
         """
         if set_id in SKIP_IN_PATH:
             raise ValueError("Empty value passed for parameter 'set_id'")
