@@ -15,10 +15,12 @@
 #  specific language governing permissions and limitations
 #  under the License.
 
+from .._async.helpers import async_bulk, async_reindex, async_scan, async_streaming_bulk
+from .._utils import fixup_module_metadata
+from .actions import _chunk_actions  # noqa: F401
+from .actions import _process_bulk_chunk  # noqa: F401
+from .actions import bulk, expand_action, parallel_bulk, reindex, scan, streaming_bulk
 from .errors import BulkIndexError, ScanError
-from .actions import expand_action, streaming_bulk, bulk, parallel_bulk
-from .actions import scan, reindex
-from .actions import _chunk_actions, _process_bulk_chunk
 
 __all__ = [
     "BulkIndexError",
@@ -29,6 +31,11 @@ __all__ = [
     "parallel_bulk",
     "scan",
     "reindex",
-    "_chunk_actions",
-    "_process_bulk_chunk",
+    "async_scan",
+    "async_bulk",
+    "async_reindex",
+    "async_streaming_bulk",
 ]
+
+fixup_module_metadata(__name__, globals())
+del fixup_module_metadata
